Pymox Reference
=================================

Mox
---

.. autoclass:: mox.Mox
   :members:
   :inherited-members:

MockAnything
------------

.. autoclass:: mox.MockAnything
   :members:
   :inherited-members:

MockObject
----------

.. autoclass:: mox.MockObject
   :members:
   :inherited-members:

MethodCallChecker
-----------------

.. autoclass:: mox.MethodCallChecker
   :members:
   :inherited-members:

MockMethod
----------

.. autoclass:: mox.MockMethod
   :members:
   :inherited-members:

Comparators
-----------

.. autoclass:: mox.Comparator
   :members:
   :inherited-members:

.. autoclass:: mox.IsA
   :members:
   :inherited-members:

.. autoclass:: mox.IsAlmost
   :members:
   :inherited-members:

.. autoclass:: mox.StrContains
   :members:
   :inherited-members:

.. autoclass:: mox.Regex
   :members:
   :inherited-members:

.. autoclass:: mox.In
   :members:
   :inherited-members:

.. autoclass:: mox.Not
   :members:
   :inherited-members:

.. autoclass:: mox.ContainsKeyValue
   :members:
   :inherited-members:

.. autoclass:: mox.ContainsAttributeValue
   :members:
   :inherited-members:

.. autoclass:: mox.SameElementsAs
   :members:
   :inherited-members:

.. autoclass:: mox.And
   :members:
   :inherited-members:

.. autoclass:: mox.Or
   :members:
   :inherited-members:

.. autoclass:: mox.Func
   :members:
   :inherited-members:

.. autoclass:: mox.IgnoreArg
   :members:
   :inherited-members:

Method Groups
-------------

.. autoclass:: mox.MethodGroup
   :members:
   :inherited-members:

.. autoclass:: mox.UnorderedGroup
   :members:
   :inherited-members:

.. autoclass:: mox.MultipleTimesGroup
   :members:
   :inherited-members:

Testing
-------

.. autoclass:: mox.MoxMetaTestBase
   :members:
   :inherited-members:

.. autoclass:: mox.MoxTestBase
   :members:
   :inherited-members:

Functions
---------

.. autoclass:: mox.Replay
   :members:
   :inherited-members:

.. autoclass:: mox.Verify
   :members:
   :inherited-members:

.. autoclass:: mox.Reset
   :members:
   :inherited-members:

Exceptions
----------

.. autoclass:: mox.Error
   :members:
   :inherited-members:

.. autoclass:: mox.ExpectedMethodCallsError
   :members:
   :inherited-members:

.. autoclass:: mox.UnexpectedMethodCallError
   :members:
   :inherited-members:

.. autoclass:: mox.UnknownMethodCallError
   :members:
   :inherited-members:

.. autoclass:: mox.PrivateAttributeError
   :members:
   :inherited-members:

.. autoclass:: mox.ExpectedMockCreationError
   :members:
   :inherited-members:

.. autoclass:: mox.UnexpectedMockCreationError
   :members:
   :inherited-members:
